<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="118"/>
        <source>Install</source>
        <translation>Installera</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="90"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Följande paket kommer att installeras. Klicka på &apos;Visa Detaljer...&apos; för information om paketen.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="98"/>
        <source>File: %1</source>
        <translation>Fil: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="115"/>
        <source>Will install the following:</source>
        <translation>Kommer att installera följande:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="130"/>
        <source>Installing selected package please authenticate</source>
        <translation>Installerar valt paket var vänlig verifiera</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="135"/>
        <source>Press any key to close</source>
        <translation>Tryck på valfri tangent för att stänga</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Program för att installera Debian binära paket (deb filer)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>filer...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Namn på .deb filer som ska installeras</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[fil...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Välj .deb filer som ska installeras</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb Filer (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Inga .deb filer fanns.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>Fil %1 inte hittad</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>Fil %1 är inte en .deb fil.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Du måste köra det här programmet som vanlig användare.</translation>
    </message>
</context>
</TS>